@@ -1,20 +1,20 @@
-use 5.008;
-
 package File::Find::Closures;
 use strict;
 
 use warnings;
 no warnings;
 
-use Carp                  qw(carp croak);
-use Exporter              qw(import);
-use File::Basename        qw(dirname);
+use vars qw( $VERSION @EXPORT_OK %EXPORT_TAGS );
+
+use Carp qw(carp croak);
+use Exporter qw(import);
+use File::Basename qw(dirname);
 use File::Spec::Functions qw(canonpath no_upwards);
-use UNIVERSAL;
+use UNIVERSAL qw(isa);
 
-our $VERSION = '1.112_101';
+$VERSION = '1.10';
 
-our @EXPORT_OK   = qw(
+@EXPORT_OK   = qw(
 	find_regular_files
 	find_by_min_size
 	find_by_max_size
@@ -32,15 +32,13 @@ our @EXPORT_OK   = qw(
 	find_by_created_before
 	find_by_created_after
 	);
-
-our %EXPORT_TAGS = (
+	
+%EXPORT_TAGS = (
 	all => \@EXPORT_OK
 	);
 
 sub _unimplemented { croak "Unimplemented function!" }
 
-=encoding utf8
-
 =head1 NAME
 
 File::Find::Closures - functions you can use with File::Find
@@ -62,7 +60,7 @@ File::Find::Closures - functions you can use with File::Find
 I wrote this module as an example of both using closures and using
 File::Find. Students are always asking me what closures are good
 for, and here's some examples. The functions mostly stand alone (i.e.
-they don't need the rest of the module), so rather than creating a
+they don't need the rest of the module), so rather than creating a 
 dependency in your code, just lift the parts you want).
 
 When I use File::Find, I have two headaches---coming up with the
@@ -96,9 +94,10 @@ Find all regular files.
 
 =cut
 
-sub find_regular_files {
+sub find_regular_files
+	{	
 	my @files = ();
-
+	
 	sub { push @files, canonpath( $File::Find::name ) if -f $_ },
 	sub { @files = no_upwards( @files ); wantarray ? @files : [ @files ] }
 	}
@@ -109,11 +108,12 @@ Find files whose size is equal to or greater than SIZE bytes.
 
 =cut
 
-sub find_by_min_size {
+sub find_by_min_size
+	{
 	my $min   = shift;
-
+	
 	my @files = ();
-
+	
 	sub { push @files, canonpath( $File::Find::name ) if -s $_ >= $min },
 	sub { @files = no_upwards( @files ); wantarray ? @files : [ @files ] }
 	}
@@ -124,11 +124,12 @@ Find files whose size is equal to or less than SIZE bytes.
 
 =cut
 
-sub find_by_max_size {
+sub find_by_max_size
+	{
 	my $min   = shift;
-
+	
 	my @files = ();
-
+	
 	sub { push @files, canonpath( $File::Find::name ) if -s $_ <= $min },
 	sub { @files = no_upwards( @files ); wantarray ? @files : [ @files ] }
 	}
@@ -139,11 +140,12 @@ Find files whose size is equal to 0 bytes.
 
 =cut
 
-sub find_by_zero_size {
+sub find_by_zero_size
+	{
 	my $min   = shift;
-
+	
 	my @files = ();
-
+	
 	sub { push @files, canonpath( $File::Find::name ) if -s $_ == 0 },
 	sub { @files = no_upwards( @files ); wantarray ? @files : [ @files ] }
 	}
@@ -155,16 +157,17 @@ as any of the values in @names.
 
 =cut
 
-sub find_by_directory_contains {
+sub find_by_directory_contains
+	{
 	my @contains = @_;
 	my %contains = map { $_, 1 } @contains;
-
+	
 	my %files = ();
 
-	sub {
+	sub { 
 		return unless exists $contains{$_};
 		my $dir = dirname( canonpath( $File::Find::name ) );
-
+			
 		$files{ $dir }++;
 		},
 
@@ -185,10 +188,11 @@ that's what you get.
 
 =cut
 
-sub find_by_name {
+sub find_by_name
+	{
 	my %hash  = map { $_, 1 } @_;
 	my @files = ();
-
+	
 	sub { push @files, canonpath( $File::Find::name ) if exists $hash{$_} },
 	sub { wantarray ? @files : [ @files ] }
 	}
@@ -202,20 +206,22 @@ that's what you get.
 
 =cut
 
-sub find_by_regex {
+sub find_by_regex
+	{
 	require File::Spec::Functions;
 	require Carp;
 	require UNIVERSAL;
-
+	
 	my $regex = shift;
-
-	unless( UNIVERSAL::isa( $regex, ref qr// ) ) {
+	
+	unless( UNIVERSAL::isa( $regex, ref qr// ) )
+		{
 		croak "Argument must be a regular expression";
 		}
-
+		
 	my @files = ();
-
-	sub { push @files,
+	
+	sub { push @files, 
 		File::Spec::Functions::canonpath( $File::Find::name ) if m/$regex/ },
 	sub { wantarray ? @files : [ @files ] }
 	}
@@ -227,11 +233,13 @@ You can also use the owner's UID.
 
 =cut
 
-sub find_by_owner {
+sub find_by_owner
+	{
 	my $id = getpwnam($_[0]);
 	   $id = $_ unless defined($id);
 
-	unless( $id =~ /\d+/ ) {
+	unless( $id =~ /\d+/ )
+		{
 		carp "Uid must be numeric of a valid system user name";
 		}
 
@@ -245,11 +253,13 @@ You can also use the group's GID.
 
 =cut
 
-sub find_by_group {
+sub find_by_group
+	{
 	my $id = getgrnam( $_[0] );
 	   $id = $_ unless defined( $id );
 
-	unless( $id =~ /\d+/ ) {
+	unless( $id =~ /\d+/ )
+		{
 		carp "Gid must be numeric or a valid system user name";
 		}
 
@@ -264,7 +274,8 @@ alternate version.
 
 =cut
 
-sub find_by_executable {
+sub find_by_executable
+	{
 	my @files = ();
 	sub { push @files, canonpath( $File::Find::name )
 			if -x },
@@ -279,7 +290,8 @@ alternate version.
 
 =cut
 
-sub find_by_writeable {
+sub find_by_writeable
+	{
 	my @files = ();
 	sub { push @files, canonpath( $File::Find::name )
 			if -w },
@@ -293,7 +305,8 @@ permissions.
 
 =cut
 
-sub find_by_umask {
+sub find_by_umask
+	{
 	my ($mask) = @_;
 
 	my @files;
@@ -311,7 +324,8 @@ systems).
 
 =cut
 
-sub find_by_modified_before {
+sub find_by_modified_before
+	{
 	return _find_by_stat_part_lessthan( $_[0], 9 );
 	}
 
@@ -323,7 +337,8 @@ systems).
 
 =cut
 
-sub find_by_modified_after {
+sub find_by_modified_after
+	{
 	return _find_by_stat_part_greaterthan( $_[0], 9 );
 	}
 
@@ -335,7 +350,8 @@ systems).
 
 =cut
 
-sub find_by_created_before {
+sub find_by_created_before
+	{
 	return _find_by_stat_part_lessthan( $_[0], 10 );
 	}
 
@@ -347,11 +363,13 @@ systems).
 
 =cut
 
-sub find_by_created_after {
+sub find_by_created_after
+	{
 	return _find_by_stat_part_greaterthan( $_[0], 10 );
 	}
 
-sub _find_by_stat_part_equal {
+sub _find_by_stat_part_equal 
+	{
 	my ($value, $stat_part) = @_;
 
 	my @files;
@@ -361,7 +379,8 @@ sub _find_by_stat_part_equal {
 	sub { wantarray ? @files : [ @files ] }
 	}
 
-sub _find_by_stat_part_lessthan {
+sub _find_by_stat_part_lessthan 
+	{
 	my ($value, $stat_part) = @_;
 
 	my @files;
@@ -371,7 +390,8 @@ sub _find_by_stat_part_lessthan {
 	sub { wantarray ? @files : [ @files ] }
 	}
 
-sub _find_by_stat_part_greaterthan {
+sub _find_by_stat_part_greaterthan 
+	{
 	my ($value, $stat_part) = @_;
 
 	my @files;
@@ -434,7 +454,7 @@ differently.
 
 This module is in Github:
 
-	https://github.com/briandfoy/file-find-closures.git
+	git://github.com/briandfoy/file-find-closures.git
 
 =head1 AUTHOR
 
@@ -444,10 +464,9 @@ Some functions implemented by Nathan Wagner, C<< <nw@hydaspes.if.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2004-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2004-2014, brian d foy, All Rights Reserved.
 
-You may redistribute this under the same terms as the Artistic License
-2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
